==> msal-1.5.4-sources.jar: com/microsoft/identity/client/ITokenShare.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.client;

import com.microsoft.identity.client.exception.MsalClientException;
import com.microsoft.identity.common.adal.internal.tokensharing.ITokenShareInternal;

/**
 * Interface defining necessary methods for TokenShareLibrary (TSL) integration.
 */
public interface ITokenShare extends ITokenShareInternal {

    /**
     * {@inheritDoc}
     */
    @Override
    String getOrgIdFamilyRefreshToken(String identifier) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    void saveOrgIdFamilyRefreshToken(String ssoStateSerializerBlob) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    String getMsaFamilyRefreshToken(String identifier) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    void saveMsaFamilyRefreshToken(String refreshToken) throws MsalClientException;

}

==> msal-2.2.0-sources.jar: com/microsoft/identity/client/ITokenShare.java <==
// Copyright (c) Microsoft Corporation.
// All rights reserved.
//
// This code is licensed under the MIT License.
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files(the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and / or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions :
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.
package com.microsoft.identity.client;

import com.microsoft.identity.client.exception.MsalClientException;
import com.microsoft.identity.common.adal.internal.tokensharing.ITokenShareInternal;
import com.microsoft.identity.common.adal.internal.tokensharing.ITokenShareResultInternal;

/**
 * Interface defining necessary methods for TokenShareLibrary (TSL) integration.
 */
public interface ITokenShare extends ITokenShareInternal {

    /**
     * {@inheritDoc}
     */
    @Override
    TokenShareResult getOrgIdFamilyRefreshTokenWithMetadata(String identifier) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    String getOrgIdFamilyRefreshToken(String identifier) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    void saveOrgIdFamilyRefreshToken(String ssoStateSerializerBlob) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    TokenShareResult getMsaFamilyRefreshTokenWithMetadata(String identifier) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    String getMsaFamilyRefreshToken(String identifier) throws MsalClientException;

    /**
     * {@inheritDoc}
     */
    @Override
    void saveMsaFamilyRefreshToken(String refreshToken) throws MsalClientException;

}
